# Shortcut Functions for Database Operations

## Install

    pip install invisibleroads-macros-database

## Test

    git clone https://github.com/invisibleroads/invisibleroads-macros-database
    cd invisibleroads-macros-database
    pip install -e .[test]
    pytest --cov=invisibleroads_macros_database --cov-report term-missing tests
